summaryrefslogtreecommitdiff
path: root/telepathy-glib/simple-observer.c
diff options
context:
space:
mode:
authorJonny Lamb <jonny.lamb@collabora.co.uk>2010-12-09 11:09:13 +0000
committerJonny Lamb <jonny.lamb@collabora.co.uk>2010-12-09 11:10:28 +0000
commitea721395cd69647d72067c53b91812fa899b8300 (patch)
treeab2e90291fc149e6701e63452d6ea9c3d7d642c4 /telepathy-glib/simple-observer.c
parent1765b4d3d3485d03927b8274846c9b6cc04492f3 (diff)
downloadtelepathy-glib-ea721395cd69647d72067c53b91812fa899b8300.tar.gz
simple-observer: fix many typos
Signed-off-by: Jonny Lamb <jonny.lamb@collabora.co.uk>
Diffstat (limited to 'telepathy-glib/simple-observer.c')
-rw-r--r--telepathy-glib/simple-observer.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/telepathy-glib/simple-observer.c b/telepathy-glib/simple-observer.c
index 6622338b1..81b0a5e69 100644
--- a/telepathy-glib/simple-observer.c
+++ b/telepathy-glib/simple-observer.c
@@ -239,7 +239,7 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
* TpSimpleObserver:callback:
*
* The TpSimpleObserverObserveChannelsImpl callback implementing the
- * ObserverChannels D-Bus method.
+ * ObserveChannels D-Bus method.
*
* This property can't be %NULL.
*
@@ -247,7 +247,7 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
*/
param_spec = g_param_spec_pointer ("callback",
"Callback",
- "Function called when ObserverChannels is called",
+ "Function called when ObserveChannels is called",
G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
g_object_class_install_property (object_class, PROP_CALLBACK,
param_spec);
@@ -256,12 +256,12 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
* TpSimpleObserver:user-data:
*
* The user-data pointer passed to the callback implementing the
- * ObserverChannels D-Bus method.
+ * ObserveChannels D-Bus method.
*
* Since: 0.11.5
*/
param_spec = g_param_spec_pointer ("user-data", "user data",
- "pointer passed as user-data when ObserverChannels is called",
+ "pointer passed as user-data when ObserveChannels is called",
G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
g_object_class_install_property (object_class, PROP_USER_DATA,
param_spec);
@@ -289,7 +289,7 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
* @recover: the value of the Observer.Recover D-Bus property
* @name: the name of the Observer (see #TpBaseClient:name: for details)
* @uniquify: the value of the #TpBaseClient:uniquify-name: property
* @callback: the function called when ObserverChannels is called
* @user_data: arbitrary user-supplied data passed to @callback
* @destroy: called with the user_data as argument, when the #TpSimpleObserver
* is destroyed
@@ -330,7 +330,7 @@ tp_simple_observer_new (TpDBusDaemon *dbus,
* @recover: the value of the Observer.Recover D-Bus property
* @name: the name of the Observer (see #TpBaseClient:name: for details)
* @uniquify: the value of the #TpBaseClient:uniquify-name: property
* @callback: the function called when ObserverChannels is called
* @user_data: arbitrary user-supplied data passed to @callback
* @destroy: called with the user_data as argument, when the #TpSimpleObserver
* is destroyed
@@ -289,7 +289,7 @@ tp_simple_observer_class_init (TpSimpleObserverClass *cls)
* @name: the name of the Observer (see #TpBaseClient:name: for details)
* @uniquify: the value of the #TpBaseClient:uniquify-name: property
- * @callback: the function called when ObserverChannels is called
+ * @callback: the function called when ObserveChannels is called
* @user_data: arbitrary user-supplied data passed to @callback
* @destroy: called with the user_data as argument, when the #TpSimpleObserver
@@ -330,7 +330,7 @@ tp_simple_observer_new (TpDBusDaemon *dbus,
* @name: the name of the Observer (see #TpBaseClient:name: for details)
* @uniquify: the value of the #TpBaseClient:uniquify-name: property
- * @callback: the function called when ObserverChannels is called
+ * @callback: the function called when ObserveChannels is called
* @user_data: arbitrary user-supplied data passed to @callback
* @destroy: called with the user_data as argument, when the #TpSimpleObserver